class WifiledPlugin():
    def __init__(self):
        pass

__title__ = 'Lisa Plugins Wifiled'
__version__ = '0.1.0'
__author__ = 'Julien Syx'
__license__ = 'Apache'
__copyright__ = 'Copyright 2015 Julien Syx'

# Version synonym
VERSION = __version__

# Header encoding (see RFC5987)
HTTP_HEADER_ENCODING = 'iso-8859-1'

# Default datetime input and output formats
ISO_8601 = 'iso-8601'




from django.db import models


class Configuration(models.Model):
    address = models.CharField(max_length=100, unique=True)
    port = models.CharField(max_length=5)
    room = models.CharField(max_length=50)


from views import ConfigurationViewSet
from rest_framework import routers
from django.conf.urls import include, url

router = routers.DefaultRouter()
router.register(r'configuration', ConfigurationViewSet)

urlpatterns = [
    url(r'^wifiled', include(router.urls)),
]


from models import Configuration
from rest_framework import viewsets
from serializers import ConfigurationSerializer


class ConfigurationViewSet(viewsets.ModelViewSet):
    """
    API endpoint that allows users to add/edit/delete shopping lists.
    """
    queryset = Configuration.objects.all()
    serializer_class = ConfigurationSerializer



from models import Configuration
from rest_framework import serializers


class ConfigurationSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = Configuration
        fields = ('room', 'address', 'port')
